@@ -88,6 +88,10 @@ class BaseGraph(object):
     def _values(self):
         return [val for serie in self.series for val in serie.values]
 
+    @cached_property
+    def _len(self):
+        return len(self.series[0].values)
+
     def _draw(self):
         self._compute()
         self._compute_margin()
@@ -98,9 +102,13 @@ class BaseGraph(object):
         self.series.append(Serie(title, values, len(self.series)))
 
     def render(self):
-        if len(self.series) == 0 or sum(
-                map(len, map(lambda s: s.values, self.series))) == 0:
-            return "No data"
+        if len(self.series) == 0:
+            return
+        for serie in self.series:
+            if not hasattr(serie.values, '__iter__'):
+                serie.values = [serie.values]
+        if sum(map(len, map(lambda s: s.values, self.series))) == 0:
+            return
         try:
             self.validate()
             self._draw()
